/**
 TUSequenceAlteration.java
 Created on February 1, 2007, 2:40 PM
 
 
 SequenceMiner: multiple anomaly classifier
 
 @author: Eugene Turkov, {eturkov@email.arc.nasa.gov}
 @version: 1.0
 
 NASA Ames Research Center
 Computational Sciences Division
 Intelligent Data Understanding Group (IDU)
 Moffett Field, CA 94035
 */

package turkov.util;

/**
 *
 * @author eturkov
 */
public class TUSequenceAlteration implements Comparable
{
    public final static String INDEX = "INDEX";
    public final static String SCORE = "SCORE";
    public final static String OBJECT = "OBJECT";
    
    /** Creates a new instance of TUSequenceAlteration */
    public TUSequenceAlteration(int index, Object object, double score)
    {
        this.index = index;
        this.object = object;
        this.score = score;
        this.itemToCompareOn = INDEX;
    }
    
    public void setObject(Object object)
    {
        this.object = object;
    }
    
    public void setCompareBy(String itemToCompareOn)
    {
        this.itemToCompareOn = itemToCompareOn;
    }
    
    public Object getObject()
    {
        return this.object;        
    }
    
    public int getIndex()
    {
        return this.index;
    }
    
    public double getScore()
    {
        return this.score;
    }    
    
    public String toString()
    {
        return this.getClass().getName() + ":index=" + this.getIndex()
        + ":object=" + this.getObject() + ":score=" + this.getScore();
    }    
    
    public int compareTo(Object object)
    {
        if(object instanceof TUSequenceAlteration)
        {
            TUSequenceAlteration sequenceAlteration = (TUSequenceAlteration)object;
            if(itemToCompareOn.equals(this.INDEX))
            {
                return this.compareToByIndex(sequenceAlteration);
            }
            
            else if(itemToCompareOn.equals(this.OBJECT))
            {
                return this.compareToByObject(sequenceAlteration);
            }

            else if(itemToCompareOn.equals(this.SCORE))
            {
                return this.compareToByScore(sequenceAlteration);
            }    
            
            else
                throw new UnsupportedOperationException("Can't compare by method: " + itemToCompareOn);
        }
        
        else
            throw new UnsupportedOperationException("Can't compare object of " +
                    "type " + object.getClass() + " to object of type " 
                    + this.getClass());
    }
    
    private int compareToByIndex(TUSequenceAlteration sequenceAlteration)
    {
        if(this.getIndex() < sequenceAlteration.getIndex())
            return -1;
        else if(this.getIndex() == sequenceAlteration.getIndex())
            return 0;
        else
            return 1;
    }
    
    private int compareToByObject(TUSequenceAlteration sequenceAlteration)
    {
        Object object = sequenceAlteration.getObject();
        if(object instanceof Comparable)
        {
            return ((Comparable)object).compareTo(this.getObject());
        }
        
        else
            throw new UnsupportedOperationException("Can't compare object of " +
                    "type " + object.getClass() + " to object of type " 
                    + this.getClass());
    }    
    
    private int compareToByScore(TUSequenceAlteration sequenceAlteration)
    {
        if(this.getScore() < sequenceAlteration.getScore())
            return -1;
        else if(this.getScore() == sequenceAlteration.getScore())
            return 0;
        else
            return 1;        
    }       
    
    private int index;
    private Object object;
    private double score;
    private String itemToCompareOn;
}
